package com.xingxi.master.ipInfo.service;

import com.xingxi.master.ipInfo.domain.IpInfo;

import java.util.List;

/**
 * 文创品牌Service接口
 *
 * @author xingxi
 * @date 2025-03-06
 */
public interface IIpInfoService {
    /**
     * 查询文创品牌
     *
     * @param ipId 文创品牌主键
     * @return 文创品牌
     */
    IpInfo selectIpInfoByIpId(Long ipId);

    /**
     * 查询文创品牌列表
     *
     * @param ipInfo 文创品牌
     * @return 文创品牌集合
     */
    List<IpInfo> selectIpInfoList(IpInfo ipInfo);

    /**
     * 新增文创品牌
     *
     * @param ipInfo 文创品牌
     * @return 结果
     */
    int insertIpInfo(IpInfo ipInfo);

    /**
     * 新增文创品牌
     *
     * @param ipInfoList 文创品牌
     * @return 结果
     */
    int batchInsertIpInfo(List<IpInfo> ipInfoList);

    /**
     * 修改文创品牌
     *
     * @param ipInfo 文创品牌
     * @return 结果
     */
    int updateIpInfo(IpInfo ipInfo);

    /**
     * 批量删除文创品牌
     *
     * @param ipIds 需要删除的文创品牌主键集合
     * @return 结果
     */
    int deleteIpInfoByIpIds(String ipIds);

    /**
     * 删除文创品牌信息
     *
     * @param ipId 文创品牌主键
     * @return 结果
     */
    int deleteIpInfoByIpId(Long ipId);

    /**
     * 逻辑删除文创品牌
     *
     * @param ipId 文创品牌主键
     * @return 结果
     */
    int logicDeleteIpInfoByIpId(Long ipId);

    /**
     * 逻辑批量删除文创品牌
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int logicDeleteIpInfoByIpIds(String ids);

    /**
     * 逻辑批量删除文创品牌
     *
     * @param ipInfo 文创品牌
     * @return 结果
     */
    int logicDeleteIpInfoByCondition(IpInfo ipInfo);
}
